@@ -517,7 +517,36 @@ class TestStackRemove(unittest.TestCase):
 
     def test_remove_unknown(self):
         conf = self.get_stack()
-        self.assertRaises(KeyError, conf.remove, 'I_do_not_exist')
+        with self.assertRaises(errors.NoSuchConfigOption):
+            conf.remove('I_do_not_exist')
+
+
+class TestStackIterMatchingOptions(unittest.TestCase):
+
+    def setUp(self):
+        super(TestStackIterMatchingOptions, self).setUp()
+        self.conf = stacks.MemoryStack()
+
+    def test_no_options(self):
+        self.assertEqual([], list(self.conf.iter_options()))
+
+    def test_options_several_sections(self):
+        self.conf.store._load_from_string('''\
+one = 1
+two = 2
+[foo]
+one = 1
+two = foo
+[bar]
+one = bar
+two = foo
+''')
+        opts = list(self.conf.iter_options())
+        assertions.assertLength(self, 6, opts)
+        self.assertEqual([(None, 'one', '1'), (None, 'two', '2'),
+                          ('foo', 'one', '1'), ('foo', 'two', 'foo'),
+                          ('bar', 'one', 'bar'), ('bar', 'two', 'foo')],
+                         [(s.id, n, v) for _, s, n, v in opts])
 
 
 class TestIterOptionRefs(unittest.TestCase):
